// eslint-disable-next-line import/no-extraneous-dependencies
import { provide, inject, ref, reactive, nextTick } from "@vue/composition-api";
import { ConfirmationManager } from "../confirmation";
const CONFIRMATION_KEY = "confirmation-manager";
export function useConfirmationHandler(options = {}) {
    let idCounter = 0;
    const confirmations = ref([]);
    const confirmationCallback = (confirmation) => {
        return new Promise((resolve) => {
            // eslint-disable-next-line no-plusplus
            const currentId = idCounter++;
            let item;
            let resolved = false;
            const removeConfirmation = () => {
                const index = confirmations.value.findIndex((c) => c.id === currentId);
                if (index >= 0) {
                    confirmations.value.splice(index, 1);
                }
            };
            const resolveConfirmation = (value) => {
                var _a;
                if (resolved)
                    return;
                resolved = true;
                resolve(!!value);
                item.active = false;
                setTimeout(removeConfirmation, (_a = options.delay) !== null && _a !== void 0 ? _a : 0);
            };
            item = reactive({
                id: currentId,
                active: false,
                confirmation: confirmation,
                resolve: resolveConfirmation,
            });
            confirmations.value.push(item);
            nextTick(() => {
                item.active = true;
            });
        });
    };
    const confirmationManager = new ConfirmationManager(confirmationCallback);
    confirmationManager.confirm = confirmationManager.confirm.bind(confirmationManager);
    provide(CONFIRMATION_KEY, confirmationManager);
    return {
        confirm: confirmationManager.confirm,
        confirmations: confirmations,
    };
}
export function useConfirm() {
    const confirmationManager = inject(CONFIRMATION_KEY);
    if (!confirmationManager)
        throw new Error(`ConfirmationManager not provided. Try useConfirmationHandler().`);
    return { confirm: confirmationManager.confirm };
}
