// eslint-disable-next-line import/no-extraneous-dependencies
import { provide, inject, ref, reactive, nextTick } from "@vue/composition-api";
import { NotificationManager } from "../notification";
const NOTIFICATION_KEY = "notification-manager";
export function useNotificationHandler(options = {}) {
    let idCounter = 0;
    const notifications = ref([]);
    const notificationCallback = (notification) => {
        // eslint-disable-next-line no-plusplus
        const currentId = idCounter++;
        let item;
        let resolved = false;
        const removeNotification = () => {
            const index = notifications.value.findIndex((c) => c.id === currentId);
            if (index >= 0) {
                notifications.value.splice(index, 1);
            }
        };
        const resolveNotification = () => {
            var _a;
            if (resolved)
                return;
            resolved = true;
            item.active = false;
            setTimeout(removeNotification, (_a = options.delay) !== null && _a !== void 0 ? _a : 0);
        };
        item = reactive({
            id: currentId,
            active: false,
            notification: notification,
            resolve: resolveNotification,
        });
        notifications.value.push(item);
        nextTick(() => {
            item.active = true;
        });
    };
    const notificationManager = new NotificationManager(notificationCallback);
    notificationManager.notify = notificationManager.notify.bind(notificationManager);
    provide(NOTIFICATION_KEY, notificationManager);
    return {
        notify: notificationManager.notify,
        notifications,
    };
}
export function useNotify() {
    const notificationManager = inject(NOTIFICATION_KEY);
    if (!notificationManager)
        throw new Error(`Notification manager not provided. Try "useNotificationHandler()".`);
    return { notify: notificationManager.notify };
}
